@@ -580,7 +580,7 @@ Kate::View* Manager::loadTemplate(TemplateItem *sel)
 		}
 	}
 
-	KileDocument::Type type = sel->type();
+	KileDocument::Type type = sel ? sel->type() : KileDocument::Undefined;
 	//always set the base directory for scripts
 	return createDocumentWithText(text, type, QString(), (type == KileDocument::Script ? m_ki->scriptManager()->getLocalJScriptDirectory() : QString()));
 }
@@ -732,6 +732,7 @@ void Manager::saveURL(const KURL & url)
 
 void Manager::newDocumentStatus(Kate::Document *doc)
 {
+	KILE_DEBUG() << "void Manager::newDocumentStatus(Kate::Document)" << endl; 
 	if (doc == 0L) return;
 
 	//sync terminal
@@ -830,6 +831,11 @@ void Manager::fileSaveAll(bool amAutoSaving, bool disUntitled )
 			}
 		}
 	}
+	/*
+	 This may look superfluos but actually it is not, in the case of multiple modified docs it ensures that the structure view keeps synchronized with the currentTextView
+	 And if we only have one masterdoc or none nothing goes wrong.
+	*/
+	emit(updateStructure(false,NULL));
 }
 
 void Manager::fileOpen(const KURL & url, const QString & encoding, int index)
@@ -936,10 +942,26 @@ void Manager::fileSaveAs(Kate::View* view)
 		}
 		break;
 	}
-	doc->setEncoding(result.encoding);
-	if(!doc->saveAs(saveURL))
-	{
-		return;
+	if(doc->encoding().lower() != result.encoding.lower()) {
+		// save the document twice if the user has selected a different encoding;
+		// this works around a bug in KatePart in the 'setEncoding' method, which 
+		// enforces a reload on every change of the encoding, and as a consequence the
+		// user sees a document-modified dialog
+		if(!doc->saveAs(saveURL))
+		{
+			return;
+		}
+		doc->setEncoding(result.encoding);
+		if(!doc->save())
+		{
+			return;
+		}
+	}
+	else {
+		if(!doc->saveAs(saveURL))
+		{
+			return;
+		}
 	}
 	if(oldURL != saveURL)
 	{
@@ -1652,9 +1674,15 @@ void Manager::storeProjectItem(KileProjectItem *item, Kate::Document *doc)
 	KILE_DEBUG() << "\titem = " << item << ", doc = " << doc << endl;
 	item->setEncoding(doc->encoding());
 	item->setHighlight(doc->hlModeName(doc->hlMode()));
-	Kate::View *view = static_cast<Kate::View*>(doc->views().first());
 	uint l = 0, c = 0;
-	if (view) view->cursorPosition(&l,&c);
+	QPtrList<KTextEditor::View> viewList = doc->views();
+	if(!viewList.isEmpty()) {
+		Kate::View *view = static_cast<Kate::View*>(viewList.first());
+	
+		if(view) {
+			view->cursorPosition(&l,&c);
+		}
+	}
 	item->setLineNumber(l);
 	item->setColumnNumber(c);
 
