@@ -13,6 +13,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "kiletoolmanager.h"
+
 #include <stdlib.h> //for getenv()
  
 #include <qstring.h>
@@ -25,7 +27,7 @@
 #include <kaction.h>
 #include <ktextedit.h>
 #include <kconfig.h>
-#include <kdebug.h>
+#include "kiledebug.h"
 #include <klocale.h>
 #include <kparts/partmanager.h>
 #include <kmessagebox.h>
@@ -35,7 +37,6 @@
 #include "kileinfo.h"
 #include "kileconfig.h"
 #include "kileproject.h"
-#include "kiletoolmanager.h"
 #include "kiletool_enums.h"
 #include "kilestdtools.h"
 #include "kilelogwidget.h"
@@ -88,13 +89,13 @@ namespace KileTool
 			Queue *oldqueue = new Queue(*this);
 
 			setAutoDelete(false); clear();
-			kdDebug() << "\tenqueueing: " << headitem->tool()->name() << endl;
+			KILE_DEBUG() << "\tenqueueing: " << headitem->tool()->name() << endl;
 			enqueue(headitem);
-			kdDebug() << "\tenqueueing: " << item->tool()->name() << endl;
+			KILE_DEBUG() << "\tenqueueing: " << item->tool()->name() << endl;
 			enqueue(item);
 			while ( oldqueue->head() )
 			{
-				kdDebug() << "\tenqueueing: " << oldqueue->head()->tool()->name() << endl;
+				KILE_DEBUG() << "\tenqueueing: " << oldqueue->head()->tool()->name() << endl;
 				enqueue(oldqueue->dequeue());
 			}
 		}
@@ -154,7 +155,7 @@ namespace KileTool
 
 	int Manager::run(Base *tool, const QString & cfg, bool insertNext /*= false*/, bool block /*= false*/)
 	{
-		kdDebug() << "==KileTool::Manager::run(Base *)============" << endl;
+		KILE_DEBUG() << "==KileTool::Manager::run(Base *)============" << endl;
 		if (m_bClear && (m_queue.count() == 0) )
 		{
 			m_log->clear();
@@ -177,7 +178,7 @@ namespace KileTool
 		else
 			m_queue.enqueue(new QueueItem(tool, cfg, block));
 
-		kdDebug() << "\tin queue: " << m_queue.count() << endl;
+		KILE_DEBUG() << "\tin queue: " << m_queue.count() << endl;
 		if ( m_queue.count() == 1 )
 			return runNextInQueue();
 		else if ( m_queue.count() > 1 )
@@ -250,7 +251,7 @@ namespace KileTool
 
 	void Manager::started(Base *tool)
 	{
-		kdDebug() << "STARTING tool: " << tool->name() << endl;
+		KILE_DEBUG() << "STARTING tool: " << tool->name() << endl;
 		m_stop->setEnabled(true);
 
 		if (tool->isViewer()) 
@@ -284,7 +285,7 @@ namespace KileTool
 		if ( result == Aborted)
 			tool->sendMessage(Error, i18n("Aborted"));
 
-		if ( result != Success && result != Silent ) //abort execution, delete all remaing tools
+		if ( result != Success && result != Silent ) //abort execution, delete all remaining tools
 		{
 			m_queue.setAutoDelete(true); m_queue.clear(); m_queue.setAutoDelete(false);
 			m_ki->outputView()->showPage(m_log);
@@ -316,8 +317,8 @@ namespace KileTool
 		QString group = (cfg == QString::null )
                     ? currentGroup(name, usequeue, useproject) : groupFor(name, cfg);
 
-		kdDebug() << "==KileTool::Manager::retrieveEntryMap=============" << endl;
-		kdDebug() << "\t" << name << " => " << group << endl;
+		KILE_DEBUG() << "==KileTool::Manager::retrieveEntryMap=============" << endl;
+		KILE_DEBUG() << "\t" << name << " => " << group << endl;
 		if ( m_config->hasGroup(group) )
 		{
 			map = m_config->entryMap(group);
@@ -346,21 +347,22 @@ namespace KileTool
 
 	void Manager::saveEntryMap(const QString & name, Config & map, bool usequeue, bool useproject)
 	{
-		kdDebug() << "==KileTool::Manager::saveEntryMap=============" << endl;
+		KILE_DEBUG() << "==KileTool::Manager::saveEntryMap=============" << endl;
 		QString group = currentGroup(name, usequeue, useproject);
-		kdDebug() << "\t" << name << " => " << group << endl;
+		KILE_DEBUG() << "\t" << name << " => " << group << endl;
 		m_config->setGroup(group);
 
 		Config::Iterator it;
 		for ( it = map.begin() ; it != map.end(); ++it)
 		{
-			m_config->writeEntry(it.key(), it.data());
+			if ( ! it.data().isEmpty() )
+				m_config->writeEntry(it.key(), it.data());
 		}
 	}
 
 	bool Manager::configure(Base *tool, const QString & cfg /*=QString::null*/)
 	{
-		kdDebug() << "==KileTool::Manager::configure()===============" << endl;
+		KILE_DEBUG() << "==KileTool::Manager::configure()===============" << endl;
 		//configure the tool
 
 		Config map;
@@ -378,13 +380,13 @@ namespace KileTool
 
 	void Manager::wantGUIState(const QString & state)
 	{
-		kdDebug() << "REQUESTED state: " << state << endl;
+		KILE_DEBUG() << "REQUESTED state: " << state << endl;
 		emit(requestGUIState(state));
 	}
 
 	QStringList toolList(KConfig *config, bool menuOnly)
 	{
-		kdDebug() << "==KileTool::toolList()==================" << endl;
+		KILE_DEBUG() << "==KileTool::toolList()==================" << endl;
 
 		QStringList groups = config->groupList(), tools;
 		QRegExp re = QRegExp("Tool/(.+)/.+");
@@ -415,7 +417,7 @@ namespace KileTool
 
 	void setConfigName(const QString & tool, const QString & name, KConfig *config)
 	{
-		kdDebug() << "==KileTool::Manager::setConfigName(" << tool << "," << name << ")===============" << endl;
+		KILE_DEBUG() << "==KileTool::Manager::setConfigName(" << tool << "," << name << ")===============" << endl;
 		config->setGroup("Tools");
 		config->writeEntry(tool, name);
 	}
@@ -427,7 +429,7 @@ namespace KileTool
 
 	QString groupFor(const QString & tool, const QString & cfg /* = Default */ )
 	{
-		return "Tool/" + tool + "/" + cfg;
+		return "Tool/" + tool + '/' + cfg;
 	}
 
 	void extract(const QString &str, QString &tool, QString &cfg)
@@ -443,13 +445,13 @@ namespace KileTool
 		}
 		else
 			tool = lcl;
-		kdDebug() << "===void extract(const QString &str = " << str << " , QString &tool = " << tool << ", QString &cfg = " << cfg << " )===" << endl;
+		KILE_DEBUG() << "===void extract(const QString &str = " << str << " , QString &tool = " << tool << ", QString &cfg = " << cfg << " )===" << endl;
 	}
 
 	QString format(const QString & tool, const QString &cfg)
 	{
 		if (!cfg.isNull())
-			return tool+"("+cfg+")";
+			return tool + '(' + cfg + ')';
 		else
 			return tool;
 	}
@@ -484,7 +486,7 @@ namespace KileTool
 
 	void setGUIOptions(const QString &tool, const QString &menu, const QString &icon, KConfig *config)
 	{
-		QString entry = menu + "," + icon;
+		QString entry = menu + ',' + icon;
 
 		config->setGroup("ToolsGUI");
 		config->writeEntry(tool, entry);
@@ -492,63 +494,18 @@ namespace KileTool
 
 	QString categoryFor(const QString &clss)
 	{
-		if ( clss == "Compile" || clss == "LaTeX" ) return "Compile";
-		if ( clss == "Convert" ) return "Convert";
-		if ( clss == "View" || clss == "ViewBib" || clss == "ViewHTML" || clss == "ForwardDVI" ) return "View";
-		if ( clss == "Sequence" ) return "Sequence";
+		if ( clss == "Compile" || clss == "LaTeX" )
+			return "Compile";
+		if ( clss == "Convert" )
+			return "Convert";
+		if ( clss == "View" || clss == "ViewBib" || clss == "ViewHTML" || clss == "ForwardDVI" )
+			return "View";
+		if ( clss == "Sequence" )
+			return "Sequence";
+		if ( clss == "Archive")
+			return "Archive";
 		return "Base";
 	}
-
-	QString expandEnvironmentVars(const QString &str)
-	{
-        static QRegExp reEnvVars("\\$(\\w+)");
-        QString result = str;
-        int index = -1;
-        while ( (index = str.find(reEnvVars, index + 1)) != -1 )
-                result.replace(reEnvVars.cap(0),getenv(reEnvVars.cap(1).local8Bit()));
-
-        return result;
-	}
-
-	QString checkOtherPaths(const QString &path,const QString &file, int type)
-	{
-		QStringList inputpaths;
-		QString configvariable;
-		QFileInfo info;
-
-		switch(type)
-		{
-				case bibinputs:
-					configvariable = KileConfig::bibInputPaths();
-				break;
-				case texinputs:
-					configvariable = KileConfig::teXPaths();
-				break;
-				case bstinputs:
-					configvariable = KileConfig::bstInputPaths();
-				break;
-				default:
-					kdDebug() << "Unknown type in checkOtherPaths" << endl;
-					return QString::null;
-				break;
-		}
-
-		inputpaths = QStringList::split( ":",  KileTool::expandEnvironmentVars(configvariable + ":$BIBINPUTS"));
-		inputpaths.prepend(path);
-
-		// the first match is supposed to be the correct one
-		for ( QStringList::Iterator it = inputpaths.begin(); it != inputpaths.end(); ++it )
- 		{
-			info.setFile((*it) + "/" + file);
-			if(info.exists())
-			{
-				kdDebug() << "filepath after correction is: " << info.dirPath() << endl;
-				return info.absFilePath();
-			}
-		}
-		return QString::null;
-	}
-
 }
 
 #include "kiletoolmanager.moc"
